@@ -5,12 +5,18 @@ import os
 import logging
 from threading import Lock
 
-LOGGER_NAME = os.environ.get("MONA_LOGGER_NAME", "mona-logger")
+# "MONA_" prefix for logger environment variables is deprecated and soon only
+# "MONA_SDK_" prefix will be accepted.
+LOGGER_NAME = os.environ.get(
+    "MONA_SDK_LOGGER_NAME", os.environ.get("MONA_LOGGER_NAME", "mona-logger")
+)
 
 # Possible logging level string values: CRITICAL, ERROR, WARNING, INFO, DEBUG, NOTSET.
 # When MONA_LOGGING_LEVEL is not provided (or holds an unknown value), logger will be
 # off.
-LOGGING_LEVEL = os.environ.get("MONA_LOGGING_LEVEL")
+LOGGING_LEVEL = os.environ.get(
+    "MONA_SDK_LOGGING_LEVEL", os.environ.get("MONA_LOGGING_LEVEL")
+)
 
 logger = None
 logger_lock = Lock()
